MediaOptions class

Constructors

MediaOptions({int imageQuality = 80, int? maxWidth = 1280, int? maxHeight = 1280, PreferredCameraDevice preferredCameraDevice = PreferredCameraDevice.auto, String? watermark, double? watermarkFontSize, double? watermarkFontSizePercentage = 4.0, String? watermarkPosition = WatermarkPosition.bottomRight, Duration? maxDuration = const Duration(seconds: 60), CropOptions? cropOptions})
const

Properties

cropOptions CropOptions?
final
hashCode int
The hash code for this object.
no setterinherited
imageQuality int
final
maxDuration Duration?
final
maxHeight int?
final
maxWidth int?
final
preferredCameraDevice PreferredCameraDevice
Preferred camera device when capturing media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
watermark String?
final
watermarkFontSize double?
final
watermarkFontSizePercentage double?
Watermark font size as a percentage of the shorter edge of the image/video. Value should be between 0 and 100. If specified, this takes precedence over watermarkFontSize. Default is 4.0 (4% of shorter edge).
final
watermarkPosition String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited